==> hippoagentsdk-0.0.43-sources.jar: com/hippoagent/model/payment/Plans.java <==
package com.hippoagent.model.payment;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

/**
 * Created by gurmail on 2019-12-05.
 *
 * @author gurmail
 */
public class Plans {
    @Expose
    @SerializedName("currency_symbol")
    private String currencySymbol;
    @Expose
    @SerializedName("description")
    private String description;
    @Expose
    @SerializedName("currency")
    private String currency;
    @Expose
    @SerializedName("amount")
    private Integer amount;
    @Expose
    @SerializedName("title")
    private String title;
    @Expose
    @SerializedName("id")
    private int id;

    public String getCurrencySymbol() {
        return currencySymbol;
    }

    public void setCurrencySymbol(String currencySymbol) {
        this.currencySymbol = currencySymbol;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public int getAmount() {
        return amount;
    }

    public void setAmount(int amount) {
        this.amount = amount;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }
}

==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/model/payment/Plans.java <==
package com.hippoagent.model.payment;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

/**
 * Created by gurmail on 2019-12-05.
 *
 * @author gurmail
 */
public class Plans {
    @Expose
    @SerializedName("currency_symbol")
    private String currencySymbol;
    @Expose
    @SerializedName("description")
    private String description;
    @Expose
    @SerializedName("currency")
    private String currency;
    @Expose
    @SerializedName("amount")
    private Double amount;
    @Expose
    @SerializedName("title")
    private String title;
    @Expose
    @SerializedName("id")
    private int id;

    public String getCurrencySymbol() {
        return currencySymbol;
    }

    public void setCurrencySymbol(String currencySymbol) {
        this.currencySymbol = currencySymbol;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public Double getAmount() {
        return amount;
    }

    public void setAmount(Double amount) {
        this.amount = amount;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }
}
